==> persian_sentiment_analyzer-0.1.6-py3-none-any.whl: persian_sentiment_analyzer/preprocessor.py <==
from hazm import Normalizer, word_tokenize, Stemmer
import re

class TextPreprocessor:
    def __init__(self):
        self.normalizer = Normalizer()
        self.stemmer = Stemmer()
        self.stopwords = set(['و' ,
'در' ,
'به' ,
'از' ,
'که' ,
'این' ,
'را' ,
'با' ,
'است' ,
'برای' ,
'آن' ,
'یک' ,
'خود' ,
'تا',
'کرد' ,
'بر' ,
'هم' ,
'نیز' ,
'گفت' ,
'می‌شود',
'وی' ,
'شد', 
'دارد' ,
'ما' ,
'اما',
'یا' ,
'شده' ,
'باید' ,
'هر' ,
'آنها' ,
'بود' ,
'او' ,
'دیگر' ,
'دو' ,
'مورد',
'می‌کند',
'شود',
'کند',
'وجود',
'بین',
'پیش',
'شده است',
'پس',
'نظر',
'اگر',
'همه',
'یکی',
'حال',
'هستند',
'من',
'کنند',
'نیست',
'باشد',
'چه',
'بی',
'می',
'بخش',
'می‌کنند',
'همین',
'افزود',
'هایی',
'دارند',
'راه',
'همچنین',
'روی',
'داد',
'بیشتر',
'بسیار',
'سه',
'داشت',
'چند',
'سوی',
'تنها',
'هیچ',
'میان',
'اینکه',
'شدن',
'بعد',
'جدید',
'ولی',
'حتی',
'کردن',
'برخی',
'کردند',
'می‌دهد',
'اول',
'نه',
'کرده است',
'نسبت',
'بیش',
'شما',
'چنین',
'طور',
'افراد',
'تمام',
'درباره',
'بار',
'بسیاری',
'می‌تواند',
'کرده',
'چون',
'ندارد',
'دوم',
'بزرگ',
'طی',
'حدود',
'همان',
'بدون',
'البته',
'آنان',
'می‌گوید',
'دیگری',
'خواهد شد',
'کنیم',
'قابل',
'یعنی',
'رشد',
'می‌توان',
'وارد',
'کل',
'ویژه',
'قبل',
'براساس',
'نیاز',
'گذاری',
'هنوز',
'لازم',
'سازی',
'بوده است',
'چرا',
'می‌شوند',
'وقتی',
'گرفت',
'کم',
'جای',
'حالی',
'تغییر',
'پیدا',
'اکنون',
'تحت',
'باعث',
'مدت',
'فقط',
'زیادی',
'تعداد',
'آیا',
'بیان',
'رو',
'شدند',
'عدم',
'کرده اند',
'بودن',
'نوع',
'بلکه',
'جاری',
'دهد',
'برابر',
'مهم',
'بوده',
'اخیر',
'مربوط',
'امر',
'زیر',
'گیری',
'شاید',
'خصوص',
'آقای',
'اثر',
'کننده',
'بودند',
'فکر',
'کنار',
'اولین',
'سوم',
'سایر',
'کنید',
'ضمن',
'مانند',
'باز',
'می‌گیرد',
'ممکن',
'حل',
'دارای',
'پی',
'مثل',
'می‌رسد',
'اجرا',
'دور',
'منظور',
'کسی',
'موجب',
'طول',
'امکان',
'آنچه',
'تعیین',
'گفته',
'شوند',
'جمع',
'خیلی',
'علاوه',
'گونه',
'تاکنون',
'رسید',
'ساله',
'گرفته',
'شده اند',
'علت',
'چهار',
'داشته باشد',
'خواهد بود',
'طرف',
'تهیه',
'تبدیل',
'مناسب',
'زیرا',
'مشخص',
'می‌توانند',
'نزدیک',
'جریان',
'روند',
'بنابراین',
'می‌دهند',
'یافت',
'نخستین',
'بالا',
'پنج',
'ریزی',
'عالی',
'چیزی',
'نخست',
'بیشتری',
'ترتیب',
'شده بود',
'خاص',
'خوبی',
'خوب',
'شروع',
'فرد',
'کامل',
'غیر',
'می‌رود',
'دهند',
'آخرین',
'دادن',
'جدی',
'بهترین',
'شامل',
'گیرد',
'بخشی',
'باشند',
'تمامی',
'بهتر',
'داده است',
'حد',
'نبود',
'کسانی',
'می‌کرد',
'داریم',
'علیه',
'می‌باشد',
'دانست',
'ناشی',
'داشتند',
'دهه',
'می‌شد',
'ایشان',
'آنجا',
'گرفته است',
'دچار',
'می‌آید',
'لحاظ',
'آنکه',
'داده',
'بعضی',
'هستیم',
'اند',
'برداری',
'نباید',
'می‌کنیم',
'نشست',
'سهم',
'همیشه',
'آمد',
'اش',
'وگو',
'می‌کنم',
'حداقل',
'طبق',
'جا',
'خواهد کرد',
'نوعی',
'چگونه',
'رفت',
'هنگام',
'فوق',
'روش',
'ندارند',
'سعی',
'بندی',
'شمار',
'کلی',
'کافی',
'مواجه',
'همچنان',
'زیاد',
'سمت',
'کوچک',
'داشته است',
'چیز',
'پشت',
'آورد',
'حالا',
'روبه',
'سال‌های',
'دادند',
'می‌کردند',
'عهده',
'نیمه',
'جایی',
'دیگران',
'سی',
'بروز',
'یکدیگر',
'آمده است',
'جز',
'کنم',
'سپس',
'کنندگان',
'خودش',
'همواره',
'یافته',
'شان',
'صرف',
'نمی‌شود',
'رسیدن',
'چهارم',
'یابد',
'متر',
'ساز',
'داشته',
'کرده بود',
'باره',
'نحوه',
'کردم',
'تو',
'شخصی',
'داشته باشند',
'محسوب',
'پخش',
'کمی',
'متفاوت',
'سراسر',
'کاملا',
'داشتن',
'نظیر',
'آمده',
'گروهی',
'فردی',
'همچون',
'خطر',
'خویش',
'کدام',
'دسته',
'سبب',
'عین',
'آوری',
'متاسفانه',
'بیرون',
'دار',
'ابتدا',
'شش',
'افرادی',
'می‌گویند',
'سالهای',
'درون',
'نیستند',
'یافته است',
'پر',
'خاطرنشان',
'گاه',
'جمعی',
'اغلب',
'دوباره',
'می‌یابد',
'لذا',
'زاده',
'گردد',
'اینجا'

            ])
    
    def preprocess_text(self, text):
        """پردازش کامل متن فارسی"""
        text = self.normalizer.normalize(str(text))
        text = re.sub(r'[\d۰-۹]+', '', text)  # حذف اعداد
        text = re.sub(r'[!()\-\[\]{};:\'"<>?@#$%^&*_~]', ' ', text)  # حذف علائم
        tokens = word_tokenize(text)
        return [
            self.stemmer.stem(token)
            for token in tokens
            if token not in self.stopwords and len(token) > 1
        ]

==> persian_sentiment_analyzer-0.1.7-py3-none-any.whl: persian_sentiment_analyzer/preprocessor.py <==
from hazm import Normalizer, word_tokenize, Stemmer
import re

class TextPreprocessor:
    def __init__(self):
        self.normalizer = Normalizer()
        self.stemmer = Stemmer()
        self.stopwords = {'و' ,
'در' ,
'به' ,
'از' ,
'که' ,
'این' ,
'را' ,
'با' ,
'است' ,
'برای' ,
'آن' ,
'یک' ,
'خود' ,
'تا',
'کرد' ,
'بر' ,
'هم' ,
'نیز' ,
'گفت' ,
'می‌شود',
'وی' ,
'شد', 
'دارد' ,
'ما' ,
'اما',
'یا' ,
'شده' ,
'باید' ,
'هر' ,
'آنها' ,
'بود' ,
'او' ,
'دیگر' ,
'دو' ,
'مورد',
'می‌کند',
'شود',
'کند',
'وجود',
'بین',
'پیش',
'شده است',
'پس',
'نظر',
'اگر',
'همه',
'یکی',
'حال',
'هستند',
'من',
'کنند',
'نیست',
'باشد',
'چه',
'بی',
'می',
'بخش',
'می‌کنند',
'همین',
'افزود',
'هایی',
'دارند',
'راه',
'همچنین',
'روی',
'داد',
'بیشتر',
'بسیار',
'سه',
'داشت',
'چند',
'سوی',
'تنها',
'هیچ',
'میان',
'اینکه',
'شدن',
'بعد',
'جدید',
'ولی',
'حتی',
'کردن',
'برخی',
'کردند',
'می‌دهد',
'اول',
'نه',
'کرده است',
'نسبت',
'بیش',
'شما',
'چنین',
'طور',
'افراد',
'تمام',
'درباره',
'بار',
'بسیاری',
'می‌تواند',
'کرده',
'چون',
'ندارد',
'دوم',
'بزرگ',
'طی',
'حدود',
'همان',
'بدون',
'البته',
'آنان',
'می‌گوید',
'دیگری',
'خواهد شد',
'کنیم',
'قابل',
'یعنی',
'رشد',
'می‌توان',
'وارد',
'کل',
'ویژه',
'قبل',
'براساس',
'نیاز',
'گذاری',
'هنوز',
'لازم',
'سازی',
'بوده است',
'چرا',
'می‌شوند',
'وقتی',
'گرفت',
'کم',
'جای',
'حالی',
'تغییر',
'پیدا',
'اکنون',
'تحت',
'باعث',
'مدت',
'فقط',
'زیادی',
'تعداد',
'آیا',
'بیان',
'رو',
'شدند',
'عدم',
'کرده اند',
'بودن',
'نوع',
'بلکه',
'جاری',
'دهد',
'برابر',
'مهم',
'بوده',
'اخیر',
'مربوط',
'امر',
'زیر',
'گیری',
'شاید',
'خصوص',
'آقای',
'اثر',
'کننده',
'بودند',
'فکر',
'کنار',
'اولین',
'سوم',
'سایر',
'کنید',
'ضمن',
'مانند',
'باز',
'می‌گیرد',
'ممکن',
'حل',
'دارای',
'پی',
'مثل',
'می‌رسد',
'اجرا',
'دور',
'منظور',
'کسی',
'موجب',
'طول',
'امکان',
'آنچه',
'تعیین',
'گفته',
'شوند',
'جمع',
'خیلی',
'علاوه',
'گونه',
'تاکنون',
'رسید',
'ساله',
'گرفته',
'شده اند',
'علت',
'چهار',
'داشته باشد',
'خواهد بود',
'طرف',
'تهیه',
'تبدیل',
'مناسب',
'زیرا',
'مشخص',
'می‌توانند',
'نزدیک',
'جریان',
'روند',
'بنابراین',
'می‌دهند',
'یافت',
'نخستین',
'بالا',
'پنج',
'ریزی',
'عالی',
'چیزی',
'نخست',
'بیشتری',
'ترتیب',
'شده بود',
'خاص',
'خوبی',
'خوب',
'شروع',
'فرد',
'کامل',
'غیر',
'می‌رود',
'دهند',
'آخرین',
'دادن',
'جدی',
'بهترین',
'شامل',
'گیرد',
'بخشی',
'باشند',
'تمامی',
'بهتر',
'داده است',
'حد',
'نبود',
'کسانی',
'می‌کرد',
'داریم',
'علیه',
'می‌باشد',
'دانست',
'ناشی',
'داشتند',
'دهه',
'می‌شد',
'ایشان',
'آنجا',
'گرفته است',
'دچار',
'می‌آید',
'لحاظ',
'آنکه',
'داده',
'بعضی',
'هستیم',
'اند',
'برداری',
'نباید',
'می‌کنیم',
'نشست',
'سهم',
'همیشه',
'آمد',
'اش',
'وگو',
'می‌کنم',
'حداقل',
'طبق',
'جا',
'خواهد کرد',
'نوعی',
'چگونه',
'رفت',
'هنگام',
'فوق',
'روش',
'ندارند',
'سعی',
'بندی',
'شمار',
'کلی',
'کافی',
'مواجه',
'همچنان',
'زیاد',
'سمت',
'کوچک',
'داشته است',
'چیز',
'پشت',
'آورد',
'حالا',
'روبه',
'سال‌های',
'دادند',
'می‌کردند',
'عهده',
'نیمه',
'جایی',
'دیگران',
'سی',
'بروز',
'یکدیگر',
'آمده است',
'جز',
'کنم',
'سپس',
'کنندگان',
'خودش',
'همواره',
'یافته',
'شان',
'صرف',
'نمی‌شود',
'رسیدن',
'چهارم',
'یابد',
'متر',
'ساز',
'داشته',
'کرده بود',
'باره',
'نحوه',
'کردم',
'تو',
'شخصی',
'داشته باشند',
'محسوب',
'پخش',
'کمی',
'متفاوت',
'سراسر',
'کاملا',
'داشتن',
'نظیر',
'آمده',
'گروهی',
'فردی',
'همچون',
'خطر',
'خویش',
'کدام',
'دسته',
'سبب',
'عین',
'آوری',
'متاسفانه',
'بیرون',
'دار',
'ابتدا',
'شش',
'افرادی',
'می‌گویند',
'سالهای',
'درون',
'نیستند',
'یافته است',
'پر',
'خاطرنشان',
'گاه',
'جمعی',
'اغلب',
'دوباره',
'می‌یابد',
'لذا',
'زاده',
'گردد',
'اینجا'
                          }
    
    def preprocess_text(self, text):
        """پردازش کامل متن فارسی"""
        text = self.normalizer.normalize(str(text))
        text = re.sub(r'[\d۰-۹]+', '', text)  # حذف اعداد
        text = re.sub(r'[!()\-\[\]{};:\'"<>?@#$%^&*_~]', ' ', text)  # حذف علائم
        tokens = word_tokenize(text)
        return [
            self.stemmer.stem(token)
            for token in tokens
            if token not in self.stopwords and len(token) > 1
        ]
